@@ -384,52 +384,34 @@ class Fasu:
             else:
 
                 log.info("Calculating covariance matrix big files method")
-                """
-                num_vars = self.natoms*3
-                aver = np.zeros(num_vars)
-                for i in range(self.numframes()):
-                    mob = aatb(self.coords(i), target, weights=weights)-target
-                    mob = mob.flatten()
-                    aver += mob
-
-                # Code to monitor the estimated time of calculus ********************************
-                loops = (num_vars*(num_vars+1)/2)*self.numframes()
-                """
-
-
                 max_ts = 10000 # TODO this should be an argument, and dependant on num atoms
                 num_blocks = self.numframes()/max_ts
-                ts_out = self.numframes() - (max_ts * num_blocks)
+                ts_out = self.numframes() - (max_ts * num_blocks) # Equivalent to ts_out = self.numframes() % max_ts
 
-                # FIRST BLOCK
-                avg = np.zeros(self.natoms*3)
-                covar = np.zeros((self.natoms*3, self.natoms*3))
-                total_ts = num_blocks + ts_out
-                trj = np.zeros((num_blocks + ts_out, self.natoms*3))
-                for j in range(num_blocks + ts_out):
-                    index = j
-                    mob = aatb(self.coords(index), target, weights=weights)-target
-                    mob = mob.flatten()
-                    avg += mob
-                    trj[index,:] = mob
-                covar = np.dot(trj.T, trj.conj())/(num_blocks + ts_out)
+                if ts_out != 0:
+                    # First block it will process the ts_out snaps witch is the same as the module (self.numframes() % max_ts)
+                    covar = np.zeros((self.natoms*3, self.natoms*3))
+                    trj = np.zeros((ts_out, self.natoms*3))
+                    for j in range(ts_out):
+                        mob = aatb(self.coords(j), target, weights=weights)-target
+                        mob = mob.flatten()
+                        trj[j,:] = mob
+                    covar = np.dot(trj.T, trj.conj())/ts_out
 
+                total_ts = ts_out  #Current number of processed frames
 
-                # LOOP ON OTHER BLOCKS
-                for i in range(1,num_blocks):
+                # Loop the rest of blocks, each one of max_ts size in order to contain the amount of used memory
+                for i in range(num_blocks):
                     trj = np.zeros((max_ts, self.natoms*3))
-                    block_avg = np.zeros(self.natoms*3)
                     for j in range(max_ts):
-                        index = i*max_ts + j
+                        index = total_ts + j
                         mob = aatb(self.coords(index), target, weights=weights)-target
                         mob = mob.flatten()
-                        block_avg += mob
                         trj[j,:] = mob
                     block_covar = np.dot(trj.T, trj.conj())/max_ts
 
-                    # now we update/merge variables
+                    # Add the current block_covar to the total covar matrix
                     covar = (covar*total_ts + block_covar*max_ts)/(total_ts+max_ts)
-                    avg = (avg*total_ts + block_avg*max_ts)/(total_ts+max_ts)
                     total_ts += max_ts
 
 
@@ -437,7 +419,7 @@ class Fasu:
             print 'Error - process ', rank, ' trying to access fasu owned by ', self.owner
             exit(1)
 
-
+        #np.savetxt(self.trajectory+str(preload)+".txt",covar)
         return covar
 
 class Cofasu:
